@@ -33,7 +33,7 @@ BEGIN
   our %EXPORT_TAGS = ( go => [@EXPORT_OK] );
 }
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 require App::MechaCPAN::Perl;
 require App::MechaCPAN::Install;
@@ -557,7 +557,7 @@ sub fetch_file
   my ( $dst_path, $dst_file, $result );
   if ( !defined $to )
   {
-    $result = humane_tmpfile( $ff->file );
+    $result = humane_tmpfile( $ff->output_file );
 
     my @splitpath = File::Spec->splitpath( $result->filename );
     $dst_path = File::Spec->catpath( @splitpath[ 0 .. 1 ] );
@@ -568,7 +568,7 @@ sub fetch_file
     if ( $to =~ m[/$] )
     {
       $dst_path = $to;
-      $dst_file = $ff->file;
+      $dst_file = $ff->output_file;
     }
     else
     {
@@ -589,7 +589,7 @@ sub fetch_file
 
   if ( !defined $where )
   {
-    my $tmpfile = File::Spec->catdir( $dst_path, $ff->file );
+    my $tmpfile = File::Spec->catdir( $dst_path, $ff->output_file );
     if ( -e $tmpfile && !-s )
     {
       unlink $tmpfile;
@@ -692,13 +692,14 @@ sub inflate_archive
     };
 
     my $err = $@;
+    my @glob = glob('*');
 
     chdir $orig;
 
     logmsg $err
       unless $error_free;
 
-    if ($success)
+    if ($success && @glob > 0)
     {
       $is_complete = 1;
       last;
